==> rapid_widgets_library-0.2.42.tar.gz: lib/custom-image-text-card.dart <==

import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

Widget buildCard(ImageTextCard cardParameters) {
  return Container(
      child: Card(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(cardParameters.borderRadius),
          ),
          elevation: cardParameters.elevation,
          shadowColor: cardParameters.shadowColor,
          child: Column(children: <Widget>[
            cardParameters.imagePath.isNotEmpty ? Container(child: Image.network(cardParameters.imagePath)) : Container(),
            Container(
              color: cardParameters.backgroundColor,
              child: Padding(
                padding: EdgeInsets.all(cardParameters.textPadding),
                child: cardParameters.text == null ? Container() : Column(children: cardParameters.text),
              ),
            )
          ])));
}

Widget buildTextCard(CardText object) {

  return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Align(
          alignment: Alignment.center,
          child: Row(children: [
            object.icon == null
                ? Container()
                : Padding(
                    padding: const EdgeInsets.only(right: 8.0),
                    child: Icon(object.icon, size: object.fontSize + 2, color: object.textColor),
                  ),
            Expanded(child: Wrap(children: [Text(object.label.isNotEmpty ? object.label : "" + object.text, softWrap: true, style: TextStyle(fontSize: object.fontSize, color: object.textColor, fontFamily: object.fontFamily))]))
          ])));
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-image-text-card.dart <==
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

import 'custom-widget-provider/custom-services.dart';

Widget buildCard(ImageTextCard cardParameters) {
  return Container(
      child: Card(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(cardParameters.borderRadius),
          ),
          elevation: cardParameters.elevation,
          shadowColor: cardParameters.shadowColor,
          child: Column(children: <Widget>[
            cardParameters.imagePath.isNotEmpty
                ? Container(child: Image.network(cardParameters.imagePath))
                : Container(),
            Container(
              color: cardParameters.backgroundColor,
              child: Padding(
                padding: EdgeInsets.all(cardParameters.textPadding),
                child: cardParameters.text == null ? Container() : Column(children: cardParameters.text),
              ),
            )
          ])));
}

Widget buildTextCard(CardText object) {
  return Padding(
      padding: const EdgeInsets.all(8.0),
      child: Align(
          alignment: Alignment.center,
          child: Row(children: [
            object.icon == null
                ? Container()
                : Padding(
                    padding: const EdgeInsets.only(right: 8.0),
                    child: Icon(object.icon, size: object.fontSize + 2, color: object.textColor),
                  ),
            Expanded(
                child: Wrap(children: [
              Text(object.label != null ? object.label : "" + object.text,
                  softWrap: true,
                  style: GoogleFonts.getFont(
                      checkFonts(object.fontFamily),
                      fontSize: object.fontSize, color: object.textColor,))
            ]))
          ])));
}
